summaryrefslogtreecommitdiffstats
path: root/src/opengl/qglframebufferobject.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/opengl/qglframebufferobject.cpp')
-rw-r--r--src/opengl/qglframebufferobject.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/opengl/qglframebufferobject.cpp b/src/opengl/qglframebufferobject.cpp
index ee932d1ab9..9a3e2a80ac 100644
--- a/src/opengl/qglframebufferobject.cpp
+++ b/src/opengl/qglframebufferobject.cpp
@@ -53,7 +53,7 @@
QT_BEGIN_NAMESPACE
-extern QImage qt_gl_read_framebuffer(const QSize&, bool, bool);
+extern QImage qt_gl_read_frame_buffer(const QSize&, bool, bool);
#define QGL_FUNC_CONTEXT const QGLContext *ctx = QGLContext::currentContext();
#define QGL_FUNCP_CONTEXT const QGLContext *ctx = QGLContext::currentContext();
@@ -1081,7 +1081,7 @@ QImage QGLFramebufferObject::toImage() const
if (!d->valid)
return QImage();
// qt_gl_read_framebuffer doesn't work on a multisample FBO
if (format().samples() != 0) {
QGLFramebufferObject temp(size(), QGLFramebufferObjectFormat());
@@ -1094,7 +1094,7 @@ QImage QGLFramebufferObject::toImage() const
bool wasBound = isBound();
if (!wasBound)
const_cast<QGLFramebufferObject *>(this)->bind();
- QImage image = qt_gl_read_framebuffer(d->size, format().internalTextureFormat() != GL_RGB, true);
+ QImage image = qt_gl_read_frame_buffer(d->size, format().internalTextureFormat() != GL_RGB, true);
if (!wasBound)
const_cast<QGLFramebufferObject *>(this)->release();
@@ -1081,7 +1081,7 @@ QImage QGLFramebufferObject::toImage() const
if (!d->valid)
return QImage();
- // qt_gl_read_framebuffer doesn't work on a multisample FBO
+ // qt_gl_read_frame_buffer doesn't work on a multisample FBO
if (format().samples() != 0) {
QGLFramebufferObject temp(size(), QGLFramebufferObjectFormat());